<?php
namespace NicolasBejean\Customer\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;

use Magento\Customer\Api\Data\CustomerInterface;

use NicolasBejean\Customer\Helper\SendCustomer;

/**
 * Class CustomerRegisterSuccess
 *
 * @category PHP
 * @package NicolasBejean\Customer\Observer
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/customer/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class CustomerRegisterSuccess implements ObserverInterface
{
    /**
     * @var SendCustomer
     */
    protected $sendCustomer;

    /**
     * CustomerRegisterSuccess constructor.
     * @param SendCustomer $sendCustomer
     */
    public function __construct(
        SendCustomer $sendCustomer
    ) {
        $this->sendCustomer = $sendCustomer;
    }

    /**
     * Execute method
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        /* Récupère l'événement */
        $event = $observer->getEvent();

        /* Vérifie si le nom de l'événement est bien celui souhaité */
        if ($event->getName() === 'customer_register_success') {
            /** @var CustomerInterface $customer */
            $customer = $observer->getData('customer');

            $this->sendCustomer->execute('frontend', $customer);
        }
    }
}
